searchNodes=[{"doc":"Provides cache and validation for confluent schemas.","ref":"ConfluentSchema.html","title":"ConfluentSchema","type":"module"},{"doc":"Validates the payload against the schema for the given subject. Examples iex&gt; ConfluentSchema . validate ( &quot;a string example&quot; , &quot;subject&quot; ) { :ok , &quot;a string example&quot; } iex&gt; ConfluentSchema . validate ( &quot;a string example&quot; , &quot;unknown-subject&quot; ) { :error , :not_found } iex&gt; ConfluentSchema . validate ( 123 , &quot;subject&quot; ) { :error , [ { &quot;Type mismatch. Expected String but got Integer.&quot; , &quot;#&quot; } ] }","ref":"ConfluentSchema.html#validate/2","title":"ConfluentSchema.validate/2","type":"function"},{"doc":"","ref":"ConfluentSchema.html#t:errors/0","title":"ConfluentSchema.errors/0","type":"type"},{"doc":"Cache Confluent schemas on ETS table.","ref":"ConfluentSchema.Cache.html","title":"ConfluentSchema.Cache","type":"module"},{"doc":"Return the cached Confluent schema for a given subject. Raise ArgumentError if cache is not started. Example iex&gt; Cache . start ( ) iex&gt; Cache . set ( &quot;my-subject&quot; , %{ &quot;type&quot; =&gt; &quot;string&quot; } ) iex&gt; Cache . get ( &quot;my-subject&quot; ) { :ok , %{ &quot;type&quot; =&gt; &quot;string&quot; } } iex&gt; Cache . start ( ) iex&gt; Cache . get ( &quot;my-subject&quot; ) { :error , :not_found }","ref":"ConfluentSchema.Cache.html#get/1","title":"ConfluentSchema.Cache.get/1","type":"function"},{"doc":"Cache the Confluent schema for a given subject. Raise ArgumentError if cache is not started. Example iex&gt; Cache . start ( ) iex&gt; Cache . set ( &quot;my-subject&quot; , %{ &quot;type&quot; =&gt; &quot;string&quot; } ) true iex&gt; assert_raise ArgumentError , fn -&gt; Cache . set ( &quot;my-subject&quot; , %{ &quot;type&quot; =&gt; &quot;string&quot; } ) end","ref":"ConfluentSchema.Cache.html#set/2","title":"ConfluentSchema.Cache.set/2","type":"function"},{"doc":"Starts cache for Confluent schemas. Must be called before cache is used. Raise ArgumentError if called more than once. Example iex&gt; Cache . start ( ) :confluent_schema_cache iex&gt; Cache . start ( ) iex&gt; assert_raise ArgumentError , fn -&gt; Cache . start ( ) end","ref":"ConfluentSchema.Cache.html#start/0","title":"ConfluentSchema.Cache.start/0","type":"function"},{"doc":"Http interface for Confluent Schema.","ref":"ConfluentSchema.Registry.html","title":"ConfluentSchema.Registry","type":"module"},{"doc":"Creates a client to interact with Confluent Schema Registry.","ref":"ConfluentSchema.Registry.html#create/1","title":"ConfluentSchema.Registry.create/1","type":"function"},{"doc":"Get the latest Confluent schemas from the server. Decode the JSON schemas into maps. Examples iex&gt; client = RegistryMock . create ( ) iex&gt; Registry . get_subject_schemas ( client ) { :ok , %{ &quot;foo&quot; =&gt; %{ &quot;type&quot; =&gt; &quot;string&quot; } , &quot;bar&quot; =&gt; %{ &quot;type&quot; =&gt; &quot;string&quot; } } } iex&gt; client = RegistryMock . create_error_subject ( ) iex&gt; Registry . get_subject_schemas ( client ) { :error , :get_subjects , 404 , &quot;Not Found&quot; } iex&gt; client = RegistryMock . create_error_schema ( ) iex&gt; Registry . get_subject_schemas ( client ) { :error , :get_schema , 404 , &quot;Not Found&quot; } iex&gt; client = RegistryMock . create_error_decode ( ) iex&gt; Registry . get_subject_schemas ( client ) { :error , :decode_schema , 1 , % Jason.DecodeError { position : 0 , token : nil , data : &quot;invalid json&quot; } }","ref":"ConfluentSchema.Registry.html#get_subject_schemas/1","title":"ConfluentSchema.Registry.get_subject_schemas/1","type":"function"},{"doc":"Server to periodically fetch and cache the latest Confluent schemas.","ref":"ConfluentSchema.Server.html","title":"ConfluentSchema.Server","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"ConfluentSchema.Server.html#child_spec/1","title":"ConfluentSchema.Server.child_spec/1","type":"function"},{"doc":"Start a server to periodically fetch and cache Confluent schemas. You can get credentials from Confluent Cloud : Login &gt; Home &gt; Environments. Or you can also spin off your own Confluent Schema Registry server. Options period - Period to update schemas (optional, default 5 minutes) debug - Enable debug logs (optional, default false) ConfluentSchemaRegistry options base_url - URL of schema registry (optional, default &quot; http://localhost:8081&quot; ) username - username for BasicAuth (optional) password - password for BasicAuth (optional) adapter - Tesla adapter config (optional) middleware - List of additional ConfluentSchemaRegistry middlewares (optional) Example opts = [ base_url : &quot;https://foobar.region.aws.confluent.cloud&quot; , username : &quot;key&quot; , password : &quot;secret&quot; ] children = [ { ConfluentSchema.Server , opts } ] Supervisor . start_link ( children , strategy : :one_for_one )","ref":"ConfluentSchema.Server.html#start_link/1","title":"ConfluentSchema.Server.start_link/1","type":"function"},{"doc":"Used on test setup to block test until server has started.","ref":"ConfluentSchema.Server.html#wait_start/0","title":"ConfluentSchema.Server.wait_start/0","type":"function"},{"doc":"Provides cache and validation for confluent schemas that are pulled from a registry. It mixes ConfluentSchemaRegistry ExJsonSchema ETS To provide fast validation for schemas registered remotely on a registry server, for example confluent.cloud .","ref":"readme.html","title":"ConfluentSchema","type":"extras"},{"doc":"def deps do [ { :confluent_schema , &quot;~&gt; 0.1.0&quot; } ] end","ref":"readme.html#installation","title":"ConfluentSchema - Installation","type":"extras"},{"doc":"On application.ex : def start ( _type , _args ) do confluent_schema_opts = [ base_url : &quot;https://foobar.region.aws.confluent.cloud&quot; , username : &quot;key&quot; , password : &quot;secret&quot; , period : :timer . minutes ( 1 ) , debug : true ] children = [ { ConfluentSchema.Server , confluent_schema_opts } ] supervisor_opts = [ strategy : :one_for_one , name : MyApp.Supervisor ] Supervisor . start_link ( children , supervisor_opts ) end Then you can use your confluent schema registry to validate payloads for a subject: payload = %{ foo : &quot;bar&quot; } ConfluentSchema . validate ( payload , &quot;my-subject&quot; ) Use the period option to customize the interval to refresh schemas on the cache. It is 5 minutes by default. Use the debug option to log errors in case schemas aren't correctly fetched from the registry.","ref":"readme.html#usage","title":"ConfluentSchema - Usage","type":"extras"}]